@@ -16,19 +16,19 @@ from skimage.registration import phase_cross_correlation
 def itrack_peak(images, row_slice=None, col_slice=None, precision=1 / 10):
     """
     Generator function that tracks a diffraction peak in a stream of images.
-    
+
     Parameters
     ----------
     images : iterable of array-like
         Iterable of diffraction images. This function also supports generators.
     row_slice : slice or None, optional
-        Slice object for which image rows to use. If None (default), all rows are used. 
+        Slice object for which image rows to use. If None (default), all rows are used.
     col_slice : slice or None, optional
         Slice object for which image columns to use. If None (default), all columns are used.
     precision : float, optional
         Precision of the tracking in pixels. A precision of 1/10 (default) means that
         the tracking will be precise up to 1/10 of a pixel.
-    
+
     Yields
     ------
     shift : `~numpy.ndarray`, shape (2,)
@@ -52,11 +52,16 @@ def itrack_peak(images, row_slice=None, col_slice=None, precision=1 / 10):
 
     for image in images:
         sub[:] = image[row_slice, col_slice]
-        shift, *_ = phase_cross_correlation(reference_image=ref, moving_image=sub, upsample_factor=int(1 / precision))
+        shift = phase_cross_correlation(
+            reference_image=ref,
+            moving_image=sub,
+            return_error=False,
+            upsample_factor=int(1 / precision),
+        )
         yield np.asarray(shift)
 
 
-def align(image, reference, mask=None, fill_value=0.0, fast=None):
+def align(image, reference, mask=None, fill_value=0.0):
     """
     Align a diffraction image to a reference. Subpixel resolution available.
 
@@ -70,34 +75,27 @@ def align(image, reference, mask=None, fill_value=0.0, fast=None):
         Mask that evaluates to True on valid pixels of the array `image`.
     fill_value : float, optional
         Edges will be filled with `fill_value` after alignment.
-    fast : bool, optional
-        This parameter is deprecated, and has no effect.
-    
+
     Returns
     -------
     aligned : `~numpy.ndarray`, shape (M,N)
         Aligned image.
-    
+
     See Also
     --------
     ialign : generator of aligned images
     """
-    if fast is not None:
-        warn(
-            "skued.align: `fast` argument is deprecated and has no effect."
-        )
-
-    if mask is None:
-        mask = np.ones_like(image, dtype=np.bool)
-
-    shift, *_ = phase_cross_correlation(
-        reference_image=image, moving_image=reference, reference_mask=mask
+    shift = phase_cross_correlation(
+        reference_image=reference,
+        moving_image=image,
+        reference_mask=mask,
+        return_error=False,
     )
-    return ndi.shift(image, shift, order=2, mode="constant", cval=fill_value)
+    return ndi.shift(image, shift=shift, order=2, mode="constant", cval=fill_value)
 
 
 @array_stream
-def ialign(images, reference=None, mask=None, fill_value=0.0, fast=None):
+def ialign(images, reference=None, mask=None, fill_value=0.0):
     """
     Generator of aligned diffraction images.
 
@@ -113,8 +111,6 @@ def ialign(images, reference=None, mask=None, fill_value=0.0, fast=None):
         Mask that evaluates to True on valid pixels.
     fill_value : float, optional
         Edges will be filled with `fill_value` after alignment.
-    fast : bool, optional
-        This parameter is deprecated, and has no effect.
 
     Yields
     ------
@@ -125,9 +121,6 @@ def ialign(images, reference=None, mask=None, fill_value=0.0, fast=None):
     --------
     skued.align : align a single diffraction pattern onto a reference.
     """
-    if fast is not None:
-        warn("skued.ialign: `fast` argument is deprecated and has no effect.")
-
     images = iter(images)
 
     if reference is None:
@@ -135,12 +128,6 @@ def ialign(images, reference=None, mask=None, fill_value=0.0, fast=None):
         yield reference
 
     yield from map(
-        partial(align, reference=reference, mask=mask, fill_value=fill_value), images,
-    )
-
-
-def _crop_to_half(image, copy=False):
-    nrows, ncols = np.array(image.shape) / 4
-    return np.array(
-        image[int(nrows) : -int(nrows), int(ncols) : -int(ncols)], copy=copy
+        partial(align, reference=reference, mask=mask, fill_value=fill_value),
+        images,
     )
