@@ -4,14 +4,14 @@ Image manipulation involving symmetry
 =====================================
 """
 import numpy as np
-from npstreams import average, nan_to_num
+import npstreams as ns
 from skimage.transform import rotate
 
 from ..array_utils import mirror
 
 
 def nfold(im, mod, center=None, mask=None, fill_value=0.0):
-    """ 
+    """
     Returns an images averaged according to n-fold rotational symmetry. This can be used to
     boost the signal-to-noise ratio on an image with known symmetry, e.g. a diffraction pattern.
 
@@ -20,12 +20,12 @@ def nfold(im, mod, center=None, mask=None, fill_value=0.0):
     im : array_like, ndim 2
         Image to be azimuthally-symmetrized.
     center : array_like, shape (2,) or None, optional
-        Coordinates of the center (in pixels). If ``center=None``, the image is rotated around
-        its center, i.e. ``center=(rows / 2 - 0.5, cols / 2 - 0.5)``.
+        Coordinates of the center (in pixels) in the format ``center=[col, row]``. If ``center=None``,
+        the image is rotated around its center, i.e. ``center=(cols / 2 - 0.5, rows / 2 - 0.5)``.
     mod : int
         Fold symmetry number. Valid numbers must be a divisor of 360.
     mask : `~numpy.ndarray` or None, optional
-        Mask of `image`. The mask should evaluate to `True` (or 1) on valid pixels. 
+        Mask of `image`. The mask should evaluate to `True` (or 1) on valid pixels.
         If None (default), no mask is used.
     fill_value : float, optional
         In the case of a mask that overlaps with itself when rotationally averaged,
@@ -46,22 +46,34 @@ def nfold(im, mod, center=None, mask=None, fill_value=0.0):
         )
     angles = range(0, 360, int(360 / mod))
 
-    # Data-type must be float because of use of NaN
-    im = np.array(im, dtype=np.float, copy=True)
-
-    if mask is not None:
-        im[np.logical_not(mask)] = np.nan
+    im = np.array(im, copy=True)
 
     kwargs = {"center": center, "mode": "constant", "cval": 0, "preserve_range": True}
 
+    if mask is None:
+        return ns.average(rotate(im, angle, **kwargs) for angle in angles)
+
     # Use weights because edges of the pictures, which might be cropped by the rotation
     # should not count in the average
-    wt = np.ones_like(im, dtype=np.uint8)
-    weights = (rotate(wt, angle, **kwargs) for angle in angles)
-    rotated = (rotate(im, angle, **kwargs) for angle in angles)
+    wt = np.ones_like(mask, dtype=im.dtype)
+    wt[np.logical_not(mask)] = 0
 
-    avg = average(rotated, weights=weights, ignore_nan=True)
-    return nan_to_num(avg, fill_value, copy=False)
+    weights = (rotate(wt, angle, **kwargs) for angle in angles)
+    imgs = (rotate(im, angle, **kwargs) for angle in angles)
+
+    avg = ns.average(imgs, weights=weights)
+
+    # Mask may overlap with itself during symmetrization. At those points, the average
+    # will be zero (because the weights are 0 there)
+    # However, because users may want to change that value to `fill_value != 0`, we need
+    # to know where is the overlap
+    if fill_value != 0.0:
+        invalid_pixels = np.logical_not(mask)
+        masks = (rotate(invalid_pixels, angle, **kwargs) for angle in angles)
+        overlap = ns.prod(masks).astype(np.bool)  # equivalent to logical_and
+        avg[overlap] = fill_value
+
+    return ns.nan_to_num(avg, fill_value=fill_value)
 
 
 def reflection(im, angle, center=None, mask=None, fill_value=0.0):
@@ -81,7 +93,7 @@ def reflection(im, angle, center=None, mask=None, fill_value=0.0):
         Coordinates of the center (in pixels). If ``center=None``, the image is rotated around
         its center, i.e. ``center=(rows / 2 - 0.5, cols / 2 - 0.5)``.
     mask : `~numpy.ndarray` or None, optional
-        Mask of `image`. The mask should evaluate to `True` (or 1) on valid pixels. 
+        Mask of `image`. The mask should evaluate to `True` (or 1) on valid pixels.
         If None (default), no mask is used.
     fill_value : float, optional
         In the case of a mask that overlaps with itself when rotationally averaged,
@@ -98,10 +110,9 @@ def reflection(im, angle, center=None, mask=None, fill_value=0.0):
     im = np.array(im, dtype=np.float, copy=True)
     reflected = np.array(im, copy=True)  # reflected image
 
-    if mask is not None:
-        invalid_pixels = np.logical_not(mask)
-        im[invalid_pixels] = np.nan
-        reflected[invalid_pixels] = np.nan
+    if mask is None:
+        mask = np.ones_like(im, dtype=np.bool)
+    invalid_pixels = np.logical_not(mask)
 
     kwargs = {"center": center, "mode": "constant", "cval": 0, "preserve_range": True}
 
@@ -109,8 +120,16 @@ def reflection(im, angle, center=None, mask=None, fill_value=0.0):
     # Flip the image along the y-axis
     # Rotate back to original orientation
     # FIXME: this will not work properly for images that are offcenter
-    reflected = rotate(reflected, -angle, **kwargs)
-    reflected = mirror(reflected, axes=0)
-    reflected = rotate(reflected, angle, **kwargs)
+    def refl(arr):
+        arr = rotate(arr, -angle, **kwargs)
+        arr = mirror(arr, axes=0)
+        arr = rotate(arr, angle, **kwargs)
+        return arr
 
-    return nan_to_num(average([im, reflected]), fill_value, copy=False)
+    reflected = refl(reflected)
+    invalid_pixels_r = refl(invalid_pixels).astype(np.bool)
+
+    result = ns.average([im, reflected])
+    result[invalid_pixels_r] = fill_value
+
+    return result
